@@ -8,7 +8,7 @@ from pip._vendor.pkg_resources import _initialize_master_working_set
 
 
 def add_installed_packages_to_requirements_txt(args):
-    packages_names = [x.split('==')[0] for x in args if not x.startswith('-')]
+    packages_names = [x.split('==')[0] for x in args if not x.startswith('-') and x != '.']
     _initialize_master_working_set()
     get_package_data = lambda package_info: (package_info['name'], package_info['version']) \
         if isinstance(package_info, dict) else (package_info.name, package_info.version)
